==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkImageDataLIC2D.java <==
// java wrapper for vtkImageDataLIC2D object
//

package vtk;
import vtk.*;

public class vtkImageDataLIC2D extends vtkImageAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int SetContext_2(vtkRenderWindow id0);
  public int SetContext(vtkRenderWindow id0)
    { return SetContext_2(id0); }

  private native long GetContext_3();
  public vtkRenderWindow GetContext() {
    long temp = GetContext_3();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSteps_4(int id0);
  public void SetSteps(int id0)
    { SetSteps_4(id0); }

  private native int GetSteps_5();
  public int GetSteps()
    { return GetSteps_5(); }

  private native void SetStepSize_6(double id0);
  public void SetStepSize(double id0)
    { SetStepSize_6(id0); }

  private native double GetStepSize_7();
  public double GetStepSize()
    { return GetStepSize_7(); }

  private native void SetMagnification_8(int id0);
  public void SetMagnification(int id0)
    { SetMagnification_8(id0); }

  private native int GetMagnification_9();
  public int GetMagnification()
    { return GetMagnification_9(); }

  private native int GetOpenGLExtensionsSupported_10();
  public int GetOpenGLExtensionsSupported()
    { return GetOpenGLExtensionsSupported_10(); }

  public vtkImageDataLIC2D() { super(); }

  public vtkImageDataLIC2D(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv6h.pkg.tar.xz: vtk/vtkImageDataLIC2D.java <==
// java wrapper for vtkImageDataLIC2D object
//

package vtk;
import vtk.*;

public class vtkImageDataLIC2D extends vtkImageAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int SetContext_2(vtkRenderWindow id0);
  public int SetContext(vtkRenderWindow id0)
    { return SetContext_2(id0); }

  private native long GetContext_3();
  public vtkRenderWindow GetContext() {
    long temp = GetContext_3();

    if (temp == 0) return null;
    return (vtkRenderWindow)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSteps_4(int id0);
  public void SetSteps(int id0)
    { SetSteps_4(id0); }

  private native int GetSteps_5();
  public int GetSteps()
    { return GetSteps_5(); }

  private native void SetStepSize_6(double id0);
  public void SetStepSize(double id0)
    { SetStepSize_6(id0); }

  private native double GetStepSize_7();
  public double GetStepSize()
    { return GetStepSize_7(); }

  private native void SetMagnification_8(int id0);
  public void SetMagnification(int id0)
    { SetMagnification_8(id0); }

  private native int GetMagnification_9();
  public int GetMagnification()
    { return GetMagnification_9(); }

  private native int GetOpenGLExtensionsSupported_10();
  public int GetOpenGLExtensionsSupported()
    { return GetOpenGLExtensionsSupported_10(); }

  public vtkImageDataLIC2D() { super(); }

  public vtkImageDataLIC2D(long id) { super(id); }
  public native long   VTKInit();

}
